% CHEIRALITYCONSTRAINT Chooses the correct solution from 4 given ones.
%
% Usage: [R, C, i] = cheiralityConstraint(Ps, K1, K2, x1i, x2i)
%
%   Arguments:
%       Ps  - 1x4 cell array of camera matrices
%       %%Rs  - 1x4 cell array of rotation matrices
%       %%Cs  - 1x4 cell array of camera translation vectors
%       K1  - calibration matrix of first camera
%       K2  - calibration matrix of second camera
%       x1i - point correspondences in first image
%       x2i - point correspondences in second image
%
%   Returns:
%       P instead of R C
%       %%R - chosen rotation matrix
%       %%C - chosen camera translation vector
%       i - index of correct solution
%
% Chooses the correct solution for R and C from 4 supplied solutions by
% testing the cheirality constraint.
%
% See Also: POSESFROMESSENTIALMATRIX
%
% @author Hanno Jaspers
% @date 2011
function [ Pcorr correctSolution] = cheiralityConstraint(P, K1, K2, x1i, x2i)

if nargin ~= 5 || ~iscell(P)
    error 'Wrong (number of) arguments!'; 
end

[C R] = getCRfromP(P);

%% Resolve ambiguous solution

% Index of point to test
% test 11 samples
% testSamples = min(11,length(x1i));
% testIndex = randperm(length(x1i));
% testIndex = testIndex(1:testSamples); 
normVec = [0 0 1]';
correctCounter = zeros(1,4);
for s=1:length(x1i)
    for i=1:4
        X = reconstructPoint(x1i(:,s),x2i(:,s),eye(3),[0 0 0]',R{i},C{i},K1,K2);
        % Criterion is: X must be in front of both projective planes
        if normVec'*X >= 0 && (R{i}*normVec)'*(X-C{i}) >= 0
            correctCounter(i) = correctCounter(i)+1;
        end
    end
end
correctCounter
[tmp_mvalue correctSolutions] = max(correctCounter);

correctSolution = correctSolutions(1);

Rcorr = R{correctSolution};
Ccorr = C{correctSolution};
Pcorr = P{correctSolution};

% if verbose
%     fprintf('The correct solution is solution %i.\n',correctSolution);
%     fprintf('---------------------------------------------\n');
% end

end

