%CHOOSECORRECTHOMOGRAPHYDECOMPOSITION Gets the best homogr. decomposition
%   
% Usage: [ R, t, n ] = chooseCorrectHomographyDecomposition( decomp, x)
%
% Arguments:
%       H      - Homography
%       decomp - homography matrix decomposition struct as returned by
%                decomposeHomography
%       x1     - inliers used for calculating the homography; they should
%                be free from intrinsic parameters (meaning x1 = K\p)
%       x2     - inliers used for calculating the homography; they should
%                be free from intrinsic parameters (meaning x2 = K\p)
%                x1 <-> x2
%
% Returns:
%       R - 3x3 rotation matrix of the plane
%       t - 3x1 translation vector of plane
%       n - 4x1 normal of plane
%
% Decomposes homography using Faugeras SVD-based method.
%
% See also: decomposeHomography
%
% @author Hanno Jaspers
% @date 2011
function [ R, t, n ] = chooseCorrectHomographyDecomposition(H, decomp, inliers, inliers2 )

for i=1:length(decomp)
    decomp(i);
    nPositive = 0;
    for m=1:size(inliers,2)
        v2 = inliers(:,m);
        dVisibilityTest = (H(3,1)*v2(1) + H(3,2)*v2(2) + H(3,3)) / decomp(i).d;
        if dVisibilityTest > 0
            nPositive = nPositive + 1;
        end
    end
    decomp(i).nScore = -nPositive;
end

% throw out the four solutions with lowest nScore
[vals IX] = sort([decomp.nScore]);
decomp_s = decomp(IX);
decomp = decomp_s(1:4);

for i=1:length(decomp)
    nPositive = 0;
    for m=1:size(inliers,2)
        v3 = inliers(:,m);
        dVisibilityTest = v3' * decomp(i).n / decomp(i).d;
        if dVisibilityTest > 0.0
          nPositive = nPositive+1;
        end
    end
    decomp(i).nScore = -nPositive;
end

[vals IX] = sort([decomp.nScore]);
decomp_s = decomp(IX);
decomp = decomp_s(1:2);

% According to Faugeras and Lustman, ambiguity exists if the two scores are equal
% but in practive, better to look at the ratio!
dRatio = decomp(2).nScore / decomp(1).nScore;

if dRatio < 0.9 % no ambiguity!
    decomp = decomp(1);
else            % two-way ambiguity. Resolve by symmetric transfer error of all points.
    decomp  = decomp(1);
%     symmetricTransferError = [inf inf];
%     for i=1:2
%         
%         % Calculate, in both directions, the transfered points    
%         Hx1    = H*inliers;
%         invHx2 = H\inliers2;
% 
%         % Normalise so that the homogeneous scale parameter for all coordinates
%         % is 1.
%         x1     = hnormalise(x1);
%         x2     = hnormalise(x2);     
%         Hx1    = hnormalise(Hx1);
%         invHx2 = hnormalise(invHx2); 
% 
%         dSumError = sum((x1-invHx2).^2)  + sum((x2-Hx1).^2);
%         symmetricTransferError(i) = dSumError;
%     end
% 
%       if symmetricTransferError(1) <= symmetricTransferError(2)
%           decomp = decomp(1);
%       else
%           decomp = decomp(2);
%       end
end

R = decomp.R;
t = decomp.t;
n = decomp.n;

end

