function [ H ] = detectReferenceObjects(imglistind, imgnumber)
%DETECTREFERENCEOBJECTS Summary of this function goes here
%   NEEDS GLOBAL SCENE

global scene imagefolder current_ref current_img

if nargin~=2
    error('Wrong number of arguments.');
end

if isempty(scene)
    error('A global scene variable has to be present.');
end

current_img = [imglistind imgnumber];

% complete image field
if ~isfield(scene.imagelists(imglistind).images,'imagedata') || isempty(scene.imagelists(imglistind).images(imgnumber).imagedata)
    scale = 1;
    if isfield(scene.imagelists(imglistind).images,'scale') && ~isempty(scene.imagelists(imglistind).images(imgnumber).scale)
        scale = scene.imagelists(imglistind).images(imgnumber).scale;
    end
    scene.imagelists(imglistind).images(imgnumber).imagedata = imageLoader([imagefolder scene.imagelists(imglistind).images(imgnumber).filename], scale);
end

if ~isfield(scene.imagelists(imglistind),'sift')
    [frames desc] = loadSift(scene.imagelists(imglistind).images(imgnumber).imagedata);
    scene.imagelists(imglistind).images(imgnumber).sift.frames = frames;
    scene.imagelists(imglistind).images(imgnumber).sift.desc = desc;
end

imageStruct = scene.imagelists(imglistind).images(imgnumber);


%% calculate homographies
detected = zeros(1,length(scene.reference_objects));
H = cell(length(scene.reference_objects),1);
for i=1:length(scene.reference_objects)
    
    current_ref = i;
    
    % only detect this reference object, if it is enabled
    if isfield(scene.reference_objects(i),'enabled') && scene.reference_objects(i).enabled
        printlog('Trying to find reference object %d in image %d of imagelist %d. ',[i,imgnumber,imglistind]);
        
        H{i} = homography(scene.reference_objects(i).sift.frames, ...
                         scene.reference_objects(i).sift.desc, ...
                         imageStruct.sift.frames, ...
                         imageStruct.sift.desc);
        
        if ~isempty(H{i})
            [ny nx] = size(scene.reference_objects(i).imagedata);
            if sanityCheck(H{i},nx,ny)
                detected(i) = 1;
                
                camStruct = scene.cameras(strcmp(scene.imagelists(1).camera,{scene.cameras.name}));
                globRotAng = camStruct.globaldata.globalrotation;
                
                [R t] = getPoseFromHomography(H{i},...
                    camStruct.K,...
                    size(scene.reference_objects(i).imagedata),...
                    scene.reference_objects(i).dimensions);
                
                %fprintf('Distance of object: %6.2fcm\n',norm(t));
                %fprintf('Pan: %d, \tTilt: %d\n',imageStruct.pan,imageStruct.tilt);
                % rotate and translate
                
                imgRot = rotationFromPanTilt(imageStruct.pan, imageStruct.tilt);
                camGlobalRot = angle2dcm(deg2rad(globRotAng(1)),deg2rad(globRotAng(2)),deg2rad(globRotAng(3)));
                camGlobalPos = camStruct.globaldata.globalposition(1:3)';
                
                %extrinsicCam = [ camGlobalRot' -camGlobalRot'*camGlobalPos ];
                %round([t imgRot*t])
                scene.reference_objects(i).positions = [scene.reference_objects(i).positions imgRot*t];
                scene.reference_objects(i).rotations = cat(3,scene.reference_objects(i).rotations, R * imgRot);
                scene.reference_objects(i).globalpositions = [scene.reference_objects(i).globalpositions camGlobalRot'*(imgRot*t)+camGlobalPos];
                printlog(' -> Found!\n');
            else
                printlog(' -> Found but revoked\n');
                H{i} = [];
            end
        else
            printlog(' -> Not found.\n');
        end
    end
end
scene.imagelists(imglistind).images(imgnumber).reference_objects = find(detected);

%% display results
if checkVerbose(2)
    figure();
    imshow(scene.imagelists(imglistind).images(imgnumber).imagedata);
    colors = lines(length(H));
    lgnd = cell(length(H),1);
    cnt = 0;
    for i=1:length(H)
        if ~isempty(H{i})
            [ny nx] = size(scene.reference_objects(i).imagedata);
            pts = [ 0 nx nx 0 0; 0 0 ny ny 0; 1 1 1 1 1];
            pts_transf = H{i}*pts;
            pts_transf = pts_transf ./ repmat(pts_transf(3,:),3,1);
            line(pts_transf(1,:), pts_transf(2,:), 'LineWidth',2, 'Color', colors(i,:));
            cnt = cnt+1;
            lgnd{cnt} = scene.reference_objects(i).filename;
        end
    end
    if cnt > 0
        h = legend(lgnd(1:cnt));
        set(h,'Interpreter','none');
    end
end

end

% checks if the four cornerpoints of the reference image, transformed by
% the calculated homography result in a convex polygon (all angles have the
% same sign)
function [ success, angles ] = sanityCheck(H, nx, ny) 
    
    pts = [ 0 nx nx 0 ; 0 0 ny ny ; 1 1 1 1];
    pts_t = H*pts;
    pts_t = pts_t ./ repmat(pts_t(3,:),3,1);
     
    angles = zeros(1,size(pts,2));
    for i=0:size(pts,2)-1
       u = pts_t(:,mod(i-1,4)+1) - pts_t(:,mod(i,4)+1);
       v = pts_t(:,mod(i+1,4)+1) - pts_t(:,mod(i,4)+1);
       a = cross(u,v);
       
       angles(i+1) = a(3);
    end
    
    if abs(sum(sign(angles))) ~= size(pts,2)
        success = false;
    else
        success = true;
    end 
end