% GETPOINTCORRESPONDENCESWITHSIFT Get point correspondences using SIFT.
%
% Usage:   [ m1 m2 ] = getPointCorrespondencesWithSift(im1, im2)
%          [ m1 m2 FRAMES1 DESC1 FRAMES2 DESC2 ] = getPointCor...
%
% Arguments:
%       im1 - First image (grayscale double-image)
%       im2 - Second image (grayscale double-image)
% 
% Returns:
%       m1 - Point correspondences in first image
%       m2 - Point correspondences in second image
%
% Optional returns:
%       FRAMES1, DESC1, FRAMES2, DESC2 - sift-descriptors
%
% See Also: LOADSIFT, SIFTMATCH, SIFT
%
% @author Hanno Jaspers
% @date 2011
function [ m1 m2 varargout] = getPointCorrespondencesWithSift(im1, im2)

if nargin ~= 2
    error('You need two input arguments!');
end

global match_thresh
if isempty(match_thresh)
    match_thresh = 1.5;
end


   
   [FRAMES1,DESC1] = loadSift(im1);
   [FRAMES2,DESC2] = loadSift(im2);

    % get the SIFT matches as index pairs
    MATCHES = vl_ubcmatch(DESC1,DESC2,match_thresh);

    % the indices to the SIFT Features for each image
    mt1=MATCHES(1,:);
    mt2=MATCHES(2,:);

    % the point coordinates of the matching SIFT points
    m1 = [FRAMES1(1,mt1);FRAMES1(2,mt1)];
    m2 = [FRAMES2(1,mt2);FRAMES2(2,mt2)];


    nout = max(nargout,1)-2;
    if nout > 0 
       varargout(1) = {FRAMES1}; 
       varargout(2) = {DESC1};
       varargout(3) = {FRAMES2};
       varargout(4) = {DESC2};
    end

%     m1 = [ 22 610 132 503 247 391 246 390 135 486;
%           158 156 213 212 189 190 298 301 365 365];
%     m2 = [ 111 480 185 419 266 356 272 363 230 445;
%            129 137 179 176 160 161 239 235 280 264];

end