function [err] = reprojectionError(x,X,P,K,mode)
%REPROJECTIONERROR Calculates reprojection error.
%
% Usage: [err] = reprojectionError(x,X,P,K,mode)
%
% Arguments:
%       x - 2D points (matches in second image), 2xN or 3xN
%       X - 3D points such that x<->X, 3xN or 4xN
%       P - camera matrix
%       K - calibration matrix
%       mode:
%           0 - default: returns mean reprojection error
%           1 - returns vector of reprojection errors, 1xN   
%           2 - squared mean reprojection error
%           2 - median reprojection error
%
%
% @author Hanno Jaspers
% @date 2011

    if nargin < 4
        error('Not enough arguments');
    end
    if nargin < 5
        mode = 0;
    end
    
    if size(X,2)==size(x,2)
        npts = size(X,2);
    else
        error('X and x have to have the same length!');
    end
    if size(X,1)==3
        % pad X with 1
        X = [X; ones(1,npts)];
    end

    if size(x,1)==2
        % pad X with 1
        x = [x; ones(1,npts)];
    end
    
    % reproject points
    %m1_recon = K1*P1*X; m1_recon = m1_recon ./ repmat(m1_recon(3,:),3,1);
    x_repro = K*P*X; 
    x_repro = x_repro ./ repmat(x_repro(3,:),3,1);
    
    % compute square reprojection error
    %d1 = sum((m1_recon(1:2,:)-m1(1:2,:)).^2);
    d2 = sum((x_repro(1:2,:)-x(1:2,:)).^2);
    %d = (d1+d2)/2;
    
    
    if mode == 1
        err = sqrt(d2);
    elseif mode == 2
        err = mean(d2);
    elseif mode == 3
        err = median(sqrt(d2));
    else
        err = mean(sqrt(d2));
    end

end

