function [ angle ] = angleBetweenVectors( a, b )
%ANGLEBETWEENVECTORS Computes the angle (in radians) between a and b
%
% Usage:    [ angle ] = angleFromVectors( a, b )
%
% Arguments:
%       a - first vector (3x1 or 3xN)
%       b - first vector (3x1 or 3xN)
%
% Returns:
%       angle - angle (in rad) between a and b (0 ... pi), 1x1 or 1xN
%
% @author Hanno Jaspers
% @date 2011

if size(a)~=size(b)
    error('a and b have to have the same dimensions');
end

if size(a,2)>1
    angle = zeros(1,size(a,2));
    for i=1:size(a,2)
        angle(i) = angleBetweenVectors(a(:,i),b(:,i));
    end
else
   angle = atan2(norm(cross(a,b)),dot(a,b)); 
end

end

