function [h] = drawCamera(R,t,scale,figurehandle,lineprops)
% DRAWCAMERA - Draws a camera object
% Usage:    [h] = drawCamera(R,t,scale,figurehandle,lineprops)
%
% Arguments:
%       R - Camera rotation as rotation matrix
%       t - Translation of camera
%       scale - scale of camera (at scale=1: w=h=d=2)
%       figurehandle - handle of figure to plot camera into
%       lineprops    - properties of camera object lines
%
% Returns:
%       h - camera object handle
%
% Draws a camera object at a certain position t, rotated around R. The
% camera object consists of 8 lines. 4 in a square from [1,1,2] to [-1,-1,2]
% and 4 from the base point [0,0,0] to the corners.
%
% @author Hanno Jaspers
% @date 2011

if nargin < 4
   figurehandle = figure;
end
if nargin < 5
   lineprops = struct;
end
fh = figurehandle;

% cam template
fc = 2;
cam.vertices = [0 0 0;  ...  % 1
                1 1 fc;  ...  % 2
               -1 1 fc;  ...  % 3
               -1 -1 fc; ...  % 4
                1 -1 fc];     % 5
cam.faces = [ 1 2 3; 1 3 4; 1 4 5; 1 5 2; 2 3 4; 2 4 5 ];
cam.lines = [ 1 2; 1 3; 1 4; 1 5; 2 3; 3 4; 4 5; 5 1]';
cam.facecolor = 'cyan';
cam.edgecolor = 'black';


% since we computed in a left handed coordinate system, we have to invert
% the rotation angles
R = R';

cam.vertices = cam.vertices*scale;
cam.vertices = (R*cam.vertices' + repmat(t(1:3),1,length(cam.vertices)))';

figure(fh);

h = line(cam.vertices(cam.lines(:),1),cam.vertices(cam.lines(:),2),cam.vertices(cam.lines(:),3));
set(h,lineprops);

axis on;
grid on
daspect([1 1 1])
light('position',[10,-10,10])
light('position',[10, 10, 10])
set(gca,'projection','perspective')
set(gca,'CameraViewAngle',6)
set(gcf,'color', [.9,.9,.9])
xlabel('x');ylabel('y');zlabel('z'); 
view(-40,20)
rotate3d on

end
