function [ out ] = fevalmat( fnc, in )
%FEVALMAT - Evaluates function on single elements of matrix
% Usage:    [out] = fevalmat( fnc, in )
%
% Arguments:
%       fnc - Function
%       in  - Input matrix
%
% Returns:
%       out -> out = fnc(in) (element-wise)
%
% Example:
%       fnc = @rad2deg;
%       [rz ry rx] = dcm2angle(R);
%       fevalmat(fnc,[rz ry rx]);
%
% See: FEVAL
% 
% @author Hanno Jaspers
% @date 2011

if nargin ~= 2
    error('Wrong number of arguments: [out] = fevalmat(fnc, in)')
end

out = zeros(size(in));
for i=1:size(in,1)
    for j=1:size(in,2)
        out(i,j) = feval(fnc,in(i,j));
    end
end

end

