%GETCRFROMP Extracts camera center and rotation matrix from camera matrix
%
% Usage: [ C R ] = getCRfromP( P )
%
% Arguments:
%       P - camera matrix (if cell, then cell is returned)
%
% Returns:
%       C - position of camera center in world coordinate frame
%       R - rotation matrix
%
% See Also: getPfromCR
%
% @author Hanno Jaspers
% @date 2011
function [ C R ] = getCRfromP( P )
    
    if iscell(P)
       C = cell(size(P));
       R = cell(size(P));
       for i=1:size(P,1)
           for j=1:size(P,2)
               [ctmp rtmp] = getCRfromP(P{i,j});
               C{i,j} = ctmp;
               R{i,j} = rtmp;
           end
       end
    else
        if ~all(size(P)==[3 4])
           error('P has to be of size 3x4.'); 
        end

        R = P(1:3,1:3);
        t = P(1:3,4);
        C = -R'*t;
    end

end
