%GETPFROMCR Extracts camera center and rotation matrix from camera matrix
%
% Usage: [ P ] = getPfromCR( C R )
%
% Arguments:
%       C - position of camera center in world coordinate frame
%       R - rotation matrix
%
% Returns:
%       P - camera matrix
%
% See Also: getCRfromP
%
% @author Hanno Jaspers
% @date 2011
function [ P ] = getPfromCR(C, R)
    
    if iscell(C) && iscell(R)
       P = cell(size(C));
       for i=1:size(C,1)
           for j=1:size(C,2)
               [ptmp] = getPfromCR(C{i,j},R{i,j});
               P{i,j} = ptmp;
           end
       end
    else
        if size(C,1)<3 || ~all(size(R)==[3 3])
           error('C has to be of size 3x1 or 4x1 and R of size 3x3.'); 
        end

        P = [ R -R*C(1:3,1) ];
    end

end
