% IMAGELOADER Loads and resizes an image.
%
% Usage:  [ I ] = imageLoader(filename)  
%         [ I ] = imageLoader(filename, scale)
%
% Arguments:
%       filename - filename of the image
%       
% Optional arguments:
%       scale    - scaling of the image (0...1), defaults to 1
%
% Returns:
%       I - image data
% 
% Loads an image, resizes it, converts it to grayscale and to single
% precision.
%
% @author Hanno Jaspers
% @date 2011
function [ I ] = imageLoader(filename, scale)

if nargin<1
    error('Not enough arguments!');
end
if nargin<2 
    scale = 1;
end

global img_scale
if ~isempty(img_scale)
   scale = min([scale img_scale]);
end

disp(['Reading image: ' filename]);
imgInfo = imfinfo(filename);
if strcmp(imgInfo.ColorType,'truecolor')
    I = im2single(rgb2gray(imresize(imread(filename),scale)));
else
    I = im2single(imresize(imread(filename),scale));
end

end

