% JOINMATCHES Joins two set of matches.
%
% Usage:  [ matches ] = joinMatches(m1, m2)
%
% Arguments:
%       m1 - point matches in image 1 and 2, index set 2xn
%       m2 - point matches in image 2 and 3, index set 2xm
%
% Returns:
%       m - 3xk set of matches between three images
% 
% Computes set of (interest) point matches over three views by joining two
% two-view matches.
%
% @author Hanno Jaspers
% @date 2011
function [ matches ] = joinMatches( m1, m2 )

n = size(m1,2);
m = size(m2,2);

% allocate some memory
matches = zeros(3,n+m);
% current index in 'matches'
im = 1; 

for i=1:n
    
    m2_tmp = m2(:,m2(1,:)==m1(2,i));
    
    for j=1:size(m2_tmp,2)
        matches(:,im) = [m1(1:2,i); m2_tmp(2,j)];
        im = im+1;
    end

end

matches = matches(:,1:im-1);

end

