% LOADSIFT Calculates sift features and stores them in a folder
%
% Usage: [FRAMES,DESC] = loadSift(image [, suffix])
%  
% Arguments:
%       image    - matrix of the image as double values
% 
% Optional Arguments:
%       suffix   - additional suffix for hashing, string or number
% 
% Global variables:
%       The following global variables are used:
%
%       sift_folder - The storage folder for the sift keys.
%       sift_thresh - SIFT threshold.
%
% Returns:
%       FRAMES - SIFT frames
%       DESC   - SIFT descriptors
%
% SIFT keys are calculated once, and then stored in a folder,
% using the hash if the image data (actually just the diag(image) to
% improce the performance) and an optional suffix for the filename.
%
% See Also: SIFT
%
% @author Hanno Jaspers
% @date 2011

function [FRAMES,DESC] = loadSift(image, suffix)

global sift_folder sift_thresh

if nargin==1
    suffix = '0';
elseif nargin~=2
    error('Wrong number of arguments');
end
        

if isempty(sift_folder)
    sift_folder = 'sift_keys';
end

if exist(sift_folder,'dir') ~= 7
    mkdir(sift_folder);
end

if isempty(sift_thresh)
    threshold = 10;
else
    threshold = sift_thresh;
end

if isnumeric(suffix)
    suffix = num2str(suffix);
end

%pathHash   = hash([filename suffix num2str(threshold)],'SHA-1');
imageHash   = hash([threshold; diag(image)],'SHA-1');
siftFile = [sift_folder '/' imageHash '_' suffix '.mat'];

tic;
fprintf('SIFT-Calculation: ');
if exist(siftFile,'file') ~= 0
    fprintf('loading from file... ');
    load(siftFile,'FRAMES','DESC');
else
%     tic
%     [FRAMES,DESC] = sift(im2single(image),'threshold',threshold);
%     fprintf('Sift old: %f, %d founds\n',[toc size(FRAMES,2)]);
%     tic
    fprintf('calculating new... ');
    [FRAMES,DESC] = vl_sift(im2single(image),'EdgeThresh',sift_thresh);
    %fprintf('VLFeat: %fs, %d found\n',[toc, size(f,2)]);
    
    save(siftFile,'FRAMES','DESC');
end
fprintf('Done! Found %d features in %.4fs\n',[size(FRAMES,2) toc]);

end

