function [ static_cameras dynamic_cameras refobjects static_test_tripels dynamic_test_tripels] = setupSceneNewData( reset )
%SETUPSCENENEWDATA Summary of this function goes here
%   Detailed explanation goes here

if nargin~=1
    reset = false;
end

%% Scene structure
global imagefolder root_dir

imagefolder = [root_dir '/new_data/'];

%% load static camera data
eastwood_path = [imagefolder 'static_cameras/eastwood/'];
godard_path   = [imagefolder 'static_cameras/godard/'];
welles_path   = [imagefolder 'static_cameras/welles/'];
wenders_path  = [imagefolder 'static_cameras/wenders/'];

eastwood = load([eastwood_path 'K.mat']);
godard   = load([godard_path   'K.mat']);
welles   = load([welles_path   'K.mat']);
wenders  = load([wenders_path  'K.mat']);

text_format = '%s %f %f %f %f %f %f %f %f';

[eastwood_filenames eastwood_positions] = loadPositionData([eastwood_path 'positions.txt'],text_format);
[godard_filenames godard_positions]     = loadPositionData([godard_path 'positions.txt'],text_format);
[welles_filenames welles_positions]     = loadPositionData([welles_path 'positions.txt'],text_format);
[wenders_filenames wenders_positions]   = loadPositionData([wenders_path 'positions.txt'],text_format);

static_cams_filenames = [eastwood_filenames; godard_filenames; welles_filenames; wenders_filenames];
static_cams_positions = [eastwood_positions; godard_positions; welles_positions; wenders_positions];
static_cams_calib     = [repmat({eastwood.K},4,1); repmat({godard.K},4,1); repmat({welles.K},4,1); repmat({wenders.K},5,1)];
static_cams_paths     = [repmat({eastwood_path},4,1); repmat({godard_path},4,1); repmat({welles_path},4,1); repmat({wenders_path},5,1)];
static_cams_names     = [repmat({'eastwood'},4,1); repmat({'godard'},4,1); repmat({'welles'},4,1); repmat({'wenders'},5,1)];

static_cameras = struct( ...
    'name', static_cams_names, ...
    'path',static_cams_paths, ...
    'filename',static_cams_filenames, ...
    'K',static_cams_calib,...
    'position',num2cell(static_cams_positions(:,1:3)',[17,1])', ...
    'fixed_rotation',num2cell(static_cams_positions(:,4:6)',[17,1])', ... 
    'pantilt',num2cell(static_cams_positions(:,7:8)',[17,1])' ...
);
static_cameras_cell = struct2cell(static_cameras)';

for i=1:length(static_cameras)
    cam = static_cameras (i);
    R1 = angle2dcm(deg2rad(cam.fixed_rotation(3)), deg2rad(cam.fixed_rotation(2)), deg2rad(cam.fixed_rotation(1)));
    R2 = angle2dcm(0, deg2rad(-cam.pantilt(1)), deg2rad(-cam.pantilt(2)));
    R = R2*R1;
    static_cameras(i).extrinsic = getPFromCR(cam.position, R);%[R -R*cam.position];
end

%% load dynamic camera data

dynamic_path  = [imagefolder 'dynamic_camera/'];
dynamic       = load([dynamic_path  'K.mat']);
[dynamic_filenames dynamic_positions] = loadPositionData([dynamic_path 'positions.txt']);

dynamic_cameras = struct( ...
     'path',repmat({dynamic_path},length(dynamic_filenames),1), ...
     'filename',dynamic_filenames, ...
     'K', repmat({dynamic.K},length(dynamic_filenames),1), ...
     'position',num2cell(dynamic_positions(:,1:3)',[17,1])'...
);
dynamic_cameras_cell = struct2cell(dynamic_cameras)';

%% load reference object data
refobjects_path = [imagefolder 'reference_pictures/'];
[refobjects_filenames refobjects_sizes] = loadPositionData([refobjects_path 'picture_sizes.txt']);
refobjects = struct( ...
     'path',repmat({refobjects_path},length(refobjects_filenames),1), ...
     'filename',refobjects_filenames, ...
     'dimension',num2cell(refobjects_sizes(:,1:2)',[3,1])', ...
     'preferred_scale',num2cell(refobjects_sizes(:,3)) ...
);
refobjects_cell = struct2cell(refobjects)';

%% create test tripels
% a static test tripel consists of three indices: static_cam, static_cam, reference_object
static_test_tripels = getStaticTestTripels();

% a normal test tripel consists of three indices: static_cam, dynamic_cam, reference_object
dynamic_test_tripels = getDynamicTestTripels();
%disp('done');

end

function [filenames positions] = loadPositionData(path, text_format)
    
if nargin < 2
    text_format = '%s %f %f %f';
end

fid = fopen(path);
fileContent = textscan(fid,text_format,'HeaderLines',1);
fclose(fid);

filenames = fileContent{1};
positions = [fileContent{2:end}];
end

function [tripel] = getStaticTestTripels()

%  1 undist_eastwood_001.jpg
%  2 undist_eastwood_002.jpg
%  3 undist_eastwood_003.jpg
%  4 undist_eastwood_004.jpg
%  5 undist_godard_001.jpg
%  6 undist_godard_002.jpg
%  7 undist_godard_003.jpg
%  8 undist_godard_004.jpg
%  9 undist_welles_001.jpg
% 10 undist_welles_002.jpg
% 11 undist_welles_003.jpg
% 12 undist_welles_004.jpg
% 13 undist_wenders_001.jpg
% 14 undist_wenders_002.jpg
% 15 undist_wenders_003.jpg
% 16 undist_wenders_004.jpg
% 17 undist_wenders_005.jpg
% tripel = [ ... 
%     1 14 3;
%     14 1 3;
%    % 2 15 3;
%     4 9  1;
%     9 4  1;
%     9 17 1;
%     11 6 2];
%     %12 6 2];

tripel = [ ... 
    1 14 3; % 3 good, 4-18cm, 2-5px ; < 5px for good result!
    %1 15 3; % bad
    2 14 3; % 1 good, 2 avg, 8 cm 3px, 50-70cm 6-8px ; < 5px for good result!
    %2 15 3; % bad...
    3 14 3; % 1 good, 1 ok, 12cm 2px, 52cm 3px, !reprerr low for wrong pos!  ; < 4px for good result!
    3 15 3; % 2 good, 8cm 3px ; < 4px for good result!
    %4 5  1; % bad % unsure
    %4 6  1; % bad % unsure
    %4 9  1; % bad
    %4 10 1; % bad
    4 11 1; % 1 good, 1 ok, 24cm 0pxm 70cm 1px, ; !reprerr low for wrong pos! < 0px for good result!
    %4 17 1; % bad
    %9 5  1; % bad % unsure
    %9 6  1; % bad % unsure
    %9 17 1; % bad
    %10 5 1; % bad % unsure
    %10 6 1; % bad % unsure
    %10 17 1; % bad
    %11 5 1; % bad % unsure
    %11 6 1; % bad % unsure
    %11 17 1; % bad
    %11 5 2; % bad
    %11 6 2; % bad % unsure
    %11 7 2; % bad % unsure
    12 5 2; % 1 good, 3 ok, 26cm 5 px, 50cm 1-2px, 90cm 2px !reprerr low for wrong pos! < 2px for good result!
    %12 6 2; % bad % unsure
    %12 7 2; % bad % unsure
    ];

% and everything backwards again
tripel = [tripel; tripel(:,2) tripel(:,1) tripel(:,3)];

end

function [tripel] = getDynamicTestTripels()
% undist_01.jpg
% undist_02.jpg
% undist_03.jpg
% undist_04.jpg
% undist_05.jpg
% undist_06.jpg
% undist_07.jpg
% undist_08.jpg
% undist_09.jpg
% undist_10.jpg
% undist_11.jpg
% undist_12.jpg
% undist_13.jpg
% undist_14.jpg
% undist_15.jpg
% undist_16.jpg
% undist_17.jpg
% undist_18.jpg
% undist_19.jpg
% undist_20.jpg
% undist_21.jpg
% undist_22.jpg
% undist_23.jpg
% undist_24.jpg
% undist_25.jpg
% undist_26.jpg
% undist_27.jpg
% undist_28.jpg
% undist_29.jpg
% undist_30.jpg
% undist_31.jpg
% undist_32.jpg
% undist_33.jpg
% undist_34.jpg
% undist_35.jpg
% undist_36.jpg
% undist_37.jpg
% undist_38.jpg
% undist_39.jpg
% undist_40.jpg

% % A_i = static camera image indices that view reference object i
% A1 = [4 9 10 11 17];  % 5 and 6 unsure
% A2 = [5 11 12]; % 6 and 7 excluded
% A3 = [1 2 3 14 15];
% 
% % D_i = dynamic camera image indices that view reference object i
% D1 = [12:14 30:34];
% D2 = [15:19 30 32 35:39]; % 30 and 32 unsure
% D3 = [1:11 20:29 40];
% 
% tripel = zeros(length(A1)*length(D1)+length(A2)*length(D2)+length(A3)*length(D3),3);
% ind = 0;
% for k=1:length(D1)
%    for j=1:length(A1)
%        ind = ind+1;
%        tripel(ind,:) = [A1(j) D1(k) 1];
%    end
% end
% for k=1:length(D2)
%    for j=1:length(A2)
%        ind = ind+1;
%        tripel(ind,:) = [A2(j) D2(k) 2];
%    end
% end
% for k=1:length(D3)
%    for j=1:length(A3)
%        ind = ind+1;
%        tripel(ind,:) = [A3(j) D3(k) 3];
%    end
% end

tripel = [ ... 
    12 16 2; % 1 good, 7 ok, 28cm 0px, 45-56cm, 1px
    15 1 3; % 1 good, 18cm, 0.29px
    15 2 3; % good, 9cm-57cm, 0px - 10px
    15 22 3; % good, 14cm-40cm, 0 - 3px
    15 23 3; % good, 9cm-45cm, 0-10px
    15 24 3; % avg, 77-91cm, 1-2px
    15 25 3; % avg, 86-101cm, 7px-96px
    15 26 3; % avg one, 83cm, 145px, others lower
    15 27 3; % 1 good, 23cm, 9px, others also low
    15 28 3; % good, 43-65cm, 10-29px
    15 29 3; % avg, 52-58cm, 0-5px
    14 40 3; % good, 27-36cmm 2-7px
    2 7 3; % 2 good, 6cm 1px, 38cm, 32px, other reproerrs low
    2 8 3; % 1 good 1 avg, 10cm 9px, 77cm 16px
    2 9 3; % 1 good 1 ok, 29cm 117px, 56cm 17px
    2 10 3; % 2 good, 2 ok, 1 avg, 17,40,50,82cm, 1-82px
    2 11 3; % 1 good, 33cm, 6px,
    2 27 3; % 1 good 31cm 7px
    2 28 3; % 2 good, 26cm 27px, 18cm 44px
    2 29 3; % 5 good!! 8cm - 40cm, 0px - 6px
    3 5 3; % 1 good, 18cm, 2px
    3 6 3; % 1 good, 1 ok, 29cm 1px, 68cm 4px
    3 7 3; % 1 good, 19cm 0px, other rerrs low
    3 9 3; % good enough, 7cm, 9cm, many ~50cm, !!<1px!!
    3 10 3; % 4 good!! 3cm-13cm, 0px
    3 27 3; % 1 good, 2 ok, 24cm 1px, 65-72cm, 2-3px
    3 28 3; % 3 good, 5cm 6cm 16cm 0-1px, other rerrs also low
    3 29 3; % 4 good!, 6-34cm 0px
    9 12 1; % 4 good!!, 10 - 36cm, 0px
    9 13 1; % 4 good, 7 - 28cm, 0-1px, 66cm 1px
    10 13 1; % 5 good!! 9-28cm, 0px
    10 32 1; % 2 good, 1 avg, 30-35cm 0px, 87cm 0px
    10 34 1; % 1 good, 9 avg, 57-65cm 1px
    ]; 
    %12 6 2];

end