function [ output_args ] = setupSceneStructure1( reset )
%SETUPSCENESTRUCTURE1 Summary of this function goes here
%   optional argument: reset, defaults to false

% @author Hanno Jaspers
% @date 2011

if nargin~=1
    reset = false;
end

%% Scene structure
global scene imagefolder

if isempty(scene) || reset
 scene = struct( ...
    'reference_objects', struct(... %'cornerpoints', struct('tl',{},'tr',{},'bl',{},'br',{}), ...
        'filename', {}, ...
        'imagedata', {}, ...
        'dimensions', {}, ...
        'positions', {}, ...
        'globalpositions', {}, ...
        'rotations', {}, ...
        'posmean',{}, ...
        'poscov',{}), ...
    'cameras', struct(), ...
    'imagelists', struct( ...  
        'name', {}, ...
        'camera', {}, ...
        'images', struct( ...
            'filename', {}, ...
            'position', {}, ...
            'rotation', {}, ...
            'reference_objects', {} ...
    )) ...
);

% cameras = 
% 
% 1x7 struct array with fields:
%     name
%     K
%     distortion
%     globaldata
%     model

%imagelist_struct = struct( ...
%        'filename', {}, ...
%        'camera', {}, ...
%        'position', {}, ...
%        'rotation', {}, ...
%        'reference_objects', {}); % indices of detected reference objects

%% read information from files

if isempty(imagefolder)
   setupGlobalVariables();
end

% read camera calibration files
load([imagefolder '/cameracalibration/cameracalibration.mat']);
scene.cameras = cameras;


% Read reference objects file
refobject_dir = '/reference_pictures/';
fid = fopen([imagefolder refobject_dir 'pricture_sizes.txt']);
refObjects = textscan(fid,'%s %f %f %f','HeaderLines',1);
fclose(fid);

% Read curtiz image list 1
curtiz_imgs1 = '/conference_room_cameras/finca_shutters_closed_2011-03-11/curtiz_zoom-0.00_wb-indoor_20110311081146/';
fid = fopen([imagefolder curtiz_imgs1 'imagelist.txt']);
curtiz_images_1 = textscan(fid,'%s %f %f','HeaderLines',1);
fclose(fid);

% Read curtiz image list 2
curtiz_imgs2 = '/conference_room_cameras/finca_shutters_closed_2011-03-11/curtiz_zoom-0.20_wb-indoor_20110311081324/';
fid = fopen([imagefolder curtiz_imgs2 'imagelist.txt']);
curtiz_images_2 = textscan(fid,'%s %f %f','HeaderLines',1);
fclose(fid);

% Read welles image list 1
welles_imgs1 = '/conference_room_cameras/finca_shutters_closed_2011-03-11\welles_zoom-0.00_wb-indoor_20110311081148/';
fid = fopen([imagefolder welles_imgs1 'imagelist.txt']);
welles_images_1 = textscan(fid,'%s %f %f','HeaderLines',1);
fclose(fid);

% Read godard image list 1
godard_imgs1 = '/conference_room_cameras/finca_shutters_closed_2011-03-11\godard_zoom-0.00_wb-indoor_20110311081150/';
fid = fopen([imagefolder godard_imgs1 'imagelist.txt']);
godard_images_1 = textscan(fid,'%s %f %f','HeaderLines',1);
fclose(fid);


%% fill scene structure
fprintf('Initializing reference objects... ');
for i=1:length(refObjects{1})
    fprintf('%d/%d...',i,length(refObjects{1}));
    scene.reference_objects(i).filename = refObjects{1}{i};
    scene.reference_objects(i).dimensions = [refObjects{2}(i) refObjects{3}(i)];
    scene.reference_objects(i).enabled = 0;
    scene.reference_objects(i).imagedata = imageLoader([imagefolder refobject_dir refObjects{1}{i}],refObjects{4}(i));
    [frames desc] = loadSift(scene.reference_objects(i).imagedata);
    scene.reference_objects(i).sift.frames = frames;
    scene.reference_objects(i).sift.desc = desc;
end
% disable irf flyer, since it appears twice in the scene
%scene.reference_objects(1).enabled = 1;
%scene.reference_objects(2).enabled = 1;
scene.reference_objects(6).enabled = 1;
scene.reference_objects(7).enabled = 1;
scene.reference_objects(8).enabled = 1;
fprintf('Done!\n');

scene.imagelists(1).name = 'Curtiz test list 1';
scene.imagelists(1).camera = 'curtiz';
for i=1:length(curtiz_images_1{1})
    scene.imagelists(1).images(i).filename = [ curtiz_imgs1 curtiz_images_1{1}{i}];
    scene.imagelists(1).images(i).pan = curtiz_images_1{2}(i);
    scene.imagelists(1).images(i).tilt = curtiz_images_1{3}(i);
end

scene.imagelists(2).name = 'Curtiz zoom list';
scene.imagelists(2).camera = 'curtiz';
for i=1:length(curtiz_images_2{1})
    scene.imagelists(2).images(i).filename = [ curtiz_imgs2 curtiz_images_2{1}{i}];
    scene.imagelists(2).images(i).pan = curtiz_images_2{2}(i);
    scene.imagelists(2).images(i).tilt = curtiz_images_2{3}(i);
end

scene.imagelists(3).name = 'Welles 1';
scene.imagelists(3).camera = 'welles';
for i=1:length(welles_images_1{1})
    scene.imagelists(3).images(i).filename = [ welles_imgs1 welles_images_1{1}{i}];
    scene.imagelists(3).images(i).pan = welles_images_1{2}(i);
    scene.imagelists(3).images(i).tilt = welles_images_1{3}(i);
end

scene.imagelists(4).name = 'Godard 1';
scene.imagelists(4).camera = 'Godard';
for i=1:length(godard_images_1{1})
    scene.imagelists(4).images(i).filename = [ godard_imgs1 godard_images_1{1}{i}];
    scene.imagelists(4).images(i).pan = godard_images_1{2}(i);
    scene.imagelists(4).images(i).tilt = godard_images_1{3}(i);
end



end

end

